# AQAInterpreter

[![PyPI - Version](https://img.shields.io/pypi/v/AQAInterpreter.svg)](https://pypi.org/project/AQAInterpreter)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/AQAInterpreter.svg)](https://pypi.org/project/AQAInterpreter)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install AQAInterpreter
```

## License

`AQAInterpreter` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
